from setuptools import setup

setup(name='gb_distributions',
      version='0.1',
      description='Gaussian & Binomial distributions',
      packages=['gb_distributions'],
      author=['Chun-Yang Wei'],
      zip_safe=False)
